<?php
function ihafs_pro_get_term_options( $field ) {
	$args = $field->args( 'get_terms_args' );
	$args = is_array( $args ) ? $args : array();

	$args = wp_parse_args( $args, array( 'taxonomy' => 'category' ) );

	$taxonomy = $args['taxonomy'];

	$terms = (array) cmb2_utils()->wp_at_least( '4.5.0' )
		? get_terms( $args )
		: get_terms( $taxonomy, $args );

	// Initate an empty array
	$term_options = array();
	if ( ! empty( $terms ) ) {
		foreach ( $terms as $term ) {
			$term_options[ $term->term_id ] = $term->name;
		}
	}

	return $term_options;
}

function ihafs_pro_post_list_arr($post_type = 'post', $per_page = 10){
	$arr = array();

	$args = array(
		'post_type' => $post_type,
		'posts_per_page'	=> $per_page
	);

	$query = new WP_Query($args);
	while($query->have_posts()){
		$query->the_post();
		$arr[get_the_id()] = get_the_title();
	}
	wp_reset_postdata();

	return $arr;
}

add_action('cmb2_meta_boxes','ihafs_meta_boxes');
function ihafs_meta_boxes(){

	$prefix = '_ihafs_';

	$meta_box = new_cmb2_box( array(
		'id'           		 => $prefix . 'options',
		'title'        		 => esc_html__( 'Headers and Footers Script Options', 'ihafs-pro' ),
		'object_types' 		 => array('ihafs_script'),
		'context'      		 => 'normal',
		'priority'     		 => 'high',
		'show_names'         => true,
	) );

	$meta_box->add_field( array(
		'id'                 => $prefix.'code',
		'name'        		 => esc_html__( 'Script', 'ihafs-pro' ),
		'type'        		 => 'textarea_code',
	) );

	$meta_box->add_field( array(
		'id'                 => $prefix.'status',
		'name'        		 => esc_html__( 'Status', 'ihafs-pro' ),
		'type'        		 => 'select',
		'options'		     => array(
			'active'	=> 		esc_html__('Active', 'ihafs-pro'),
			'inactive'	=> 		esc_html__('Inactive', 'ihafs-pro'),
		)
	) );

	$meta_box->add_field( array(
		'id'                 => $prefix.'condition',
		'name'        		 => esc_html__( 'Condition', 'ihafs-pro' ),
		'type'        		 => 'radio',
		'options'     		 => array(
			'in_header'	=> 	esc_html__('Header - The script will be printed in the &lt;head&gt; section. ', 'ihafs-pro'),
			'in_footer'	=>  esc_html__('Footer - The script will be printed above the &lt;body&gt; section.', 'ihafs-pro')
		),
		'default'     		 => 'in_header',
	) );

	$meta_box->add_field( array(
		'id'                 => $prefix.'show_on',
		'name'        		 => esc_html__( 'Show On', 'ihafs-pro' ),
		'type'        		 => 'radio_inline',
		'options'     		 => array(
			'full_website'	=> 	esc_html__('Full Website', 'ihafs-pro'),
			'only_home'		=>  esc_html__('Only Homepage', 'ihafs-pro'),
			'only_pages'		=>  esc_html__('Only Pages', 'ihafs-pro'),
			'only_posts'		=>  esc_html__('Only Posts', 'ihafs-pro'),
			'only_categories'		=>  esc_html__('Only Categories', 'ihafs-pro'),
			'only_tags'		=>  esc_html__('Only Tags', 'ihafs-pro'),
		),
		'default'     		 => 'full_website',
	) );

	$meta_box->add_field( array(
		'id'                 => $prefix.'pages_list',
		'name'        		 => esc_html__( 'Pages List', 'ihafs-pro' ),
		'type'        		 => 'select_multiple',
		'options'     		 => ihafs_pro_post_list_arr('page'),
	) );

	$meta_box->add_field( array(
		'id'                 => $prefix.'posts_list',
		'name'        		 => esc_html__( 'Posts List', 'ihafs-pro' ),
		'type'        		 => 'select_multiple',
		'options'     		 => ihafs_pro_post_list_arr(),
	) );

	$meta_box->add_field( array(
		'id'             => $prefix.'categories_list',
		'name'       	 => esc_html__( 'Categories List', 'ihafs-pro' ),
		'type'           => 'multicheck',
		'options_cb'     => 'ihafs_pro_get_term_options',
		'get_terms_args' => array(
			'taxonomy'   => 'category',
			'hide_empty' => false,
		),
	) );


	$meta_box->add_field( array(
		'id'             => $prefix.'tags_list',
		'name'       	 => esc_html__( 'Tags List', 'ihafs-pro' ),
		'type'           => 'multicheck',
		'options_cb'     => 'ihafs_pro_get_term_options',
		'get_terms_args' => array(
			'taxonomy'   => 'post_tag',
			'hide_empty' => false,
		),
	) );

	$meta_box->add_field( array(
		'id'                 => $prefix.'exclude_pages',
		'name'        		 => esc_html__( 'Exclude Pages', 'ihafs-pro' ),
		'type'        		 => 'select_multiple',
		'options'     		 =>  ihafs_pro_post_list_arr('page'),
		'description'		 => esc_html__('Select the pages you want to exclude', 'ihafs-pro'),
	) );

	$meta_box->add_field( array(
		'id'                 => $prefix.'exclude_posts',
		'name'        		 => esc_html__( 'Exclude Posts', 'ihafs-pro' ),
		'type'        		 => 'select_multiple',
		'options'     		 =>  ihafs_pro_post_list_arr('post'),
		'description'		 => esc_html__('Select the posts you want to exclude', 'ihafs-pro'),
	) );
}